---
meta:
    title: Time Average Map
    description:
layout: component
---

## Examples

### Render of geotiff data from time average map service.

```html:preview
<terra-time-average-map
    collection="M2T1NXAER_5_12_4"
    variable="BCCMASS"
    start-date="01/01/2009"
    end-date="01/05/2009"
    location="62,5,95,40"
    bearer-token = "YOUR_BEARER_TOKEN"

></terra-time-average-map>
```
